@import url('https://fonts.googleapis.com/css2?family=JetBrains+Mono:wght@300;400;500;600;700&display=swap');
@import "tailwindcss";

/* Apply JetBrains Mono everywhere */
* {
  font-family: 'JetBrains Mono', 'Courier New', monospace;
}

/* Base page styling */
body {
  background: #f8fafc;   /* slate-50 */
  color: #334155;        /* slate-700 */
  font-family: 'JetBrains Mono', 'Courier New', monospace;
  line-height: 1.5;
}
